==> nxui-0.0.4.tgz: package/gulpfile.js <==
var gulp = require('gulp');
var postcss = require('gulp-postcss');
var autoprefixer = require('autoprefixer');
var header = require('gulp-header');
var gulpSass = require('gulp-sass');
var nano = require('gulp-cssnano');
var rename = require('gulp-rename');
var sourcemaps = require('gulp-sourcemaps');
var browserSync = require('browser-sync');
var plumber = require('gulp-plumber');
var pkg = require('./package.json');
var svgSymbols = require('gulp-svg-symbols');
var fs = require('fs');
var path = require('path')
var tap = require('gulp-tap')

// 命令: gulp server，启动本地server访问demo
gulp.task('server', function () {
  browserSync.init({
    server: {},
    port: 8888,
    startPath: '/demo/nxui'
  });
});

// 根据iconfont.ttf文件生成font.scss文件
gulp.task('iconfont', function () {
  var path = './lib/icon/';
  var scssModal = '@font-face {font-weight: normal;font-style: normal;font-family: "nxui";src: url("data:application/octet-stream;base64,[base64data]") format("truetype");}'
  var data = fs.readFile(path + 'iconfont.ttf', function (err, data) {
    if (err)throw err;
    ;
    console.log(data.toString('base64'))
    fs.writeFileSync(path + 'font.scss', scssModal.replace('[base64data]', data.toString('base64')))
  });
});
// 编译 template/page/index.scss 到 demo/dist 目录
gulp.task('css', function () {
  gulp.src('./template/page/index.scss')
    .pipe(gulpSass({outputStyle: "expanded"}))
    .pipe(rename({basename: "nxui"}))
    .pipe(gulp.dest('./demo/dist'))
    .pipe(gulpSass({outputStyle: "compressed"}))
    .pipe(rename({extname: ".min.css"}))
    .pipe(gulp.dest('./demo/dist'))
})
// 编译 demo/src/index.html 到 demo/dist 目录
gulp.task('html', function () {
  gulp.src('./demo/src/index.html')
    .pipe(tap(function (file) {
      var dir = path.dirname(file.path);
      var contents = file.contents.toString();
      contents = contents.replace(/<link\s+rel="import"\s+href="(.*)">/gi, function (match, $1) {
        var filePath = path.join(dir, $1);
        var id = path.basename(filePath, '.html');
        var content = fs.readFileSync(filePath, 'utf-8');
        return '<div class="inner-content" id="content_' + id + '">\n' + content + '\n</div>';
      })
      file.contents = new Buffer(contents);
    }))
    .pipe(gulp.dest('./demo/dist'));
})
// 编译 demo/src 下其他必要文件 到 demo/dist 目录
gulp.task('others', function () {
  gulp.src('./demo/src/demo.scss')
    .pipe(gulpSass({outputStyle: "expanded"}))
    .pipe(gulp.dest('./demo/dist'))
})
// 默认 任务
gulp.task('default', ['iconfont', 'css', 'html', 'others']);

==> nxui-0.2.0.tgz: package/gulpfile.js <==
var gulp = require('gulp');
var postcss = require('gulp-postcss');
var autoprefixer = require('autoprefixer');
var header = require('gulp-header');
var gulpSass = require('gulp-sass');
var nano = require('gulp-cssnano');
var rename = require('gulp-rename');
var sourcemaps = require('gulp-sourcemaps');
var browserSync = require('browser-sync');
var plumber = require('gulp-plumber');
var pkg = require('./package.json');
// var svgSymbols = require('gulp-svg-symbols');
var fs = require('fs');
var path = require('path')
var tap = require('gulp-tap')

// 命令: gulp server，启动本地server访问demo
gulp.task('server', function () {
  browserSync.init({
    server: {},
    port: 8888,
    startPath: '/demo/nxui'
  });
});

// 根据iconfont.ttf文件生成font.scss文件
gulp.task('iconfont', function () {
  var path = './lib/icon/';
  var scssModal = '@font-face {font-weight: normal;font-style: normal;font-family: "nx";src: url("data:application/octet-stream;base64,[base64data]") format("truetype");}'
  var data = fs.readFile(path + 'iconfont.ttf', function (err, data) {
    if (err)throw err;
    fs.writeFileSync(path + 'font.scss', scssModal.replace('[base64data]', data.toString('base64')))
  });
});
// 编译 template/page/index.scss 到 demo/dist 目录
gulp.task('css', function () {
  gulp.src('./template/page/index.scss')
    .pipe(gulpSass({outputStyle: "expanded"}))
    .pipe(rename({basename: "nxui"}))
    .pipe(gulp.dest('./demo/dist'))
    .pipe(gulpSass({outputStyle: "compressed"}))
    .pipe(rename({extname: ".min.css"}))
    .pipe(gulp.dest('./demo/dist'))
})
// 编译 demo/src/index.html 到 demo/dist 目录
gulp.task('html', function () {
  gulp.src('./demo/src/index.html')
    .pipe(tap(function (file) {
      var dir = path.dirname(file.path);
      var contents = file.contents.toString();
      contents = contents.replace(/<link\s+rel="import"\s+href="(.*)">/gi, function (match, $1) {
        var filePath = path.join(dir, $1);
        var id = path.basename(filePath, '.html');
        var content = fs.readFileSync(filePath, 'utf-8');
        return '<div class="inner-content" id="content_' + id + '">\n' + content + '\n</div>';
      })
      file.contents = new Buffer(contents);
    }))
    .pipe(gulp.dest('./demo/dist'));
})
// 编译 demo/src 下其他必要文件 到 demo/dist 目录
gulp.task('others', function () {
  gulp.src('./demo/src/demo.scss')
    .pipe(gulpSass({outputStyle: "expanded"}))
    .pipe(gulp.dest('./demo/dist'))
})
// 默认 任务
gulp.task('default', ['iconfont', 'css', 'html', 'others']);
